==> portmanager-0.2.9.tar.gz: portmanager-0.2.9/libMG/src/MGdbGet.c <==
/************************************************************************/
/*	Copyright (C) 2005  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

char*	MGdbGet(classDb* db, int recordIdx, char* fieldName )
{
	char	id[]	= "MGdbGet";

	/* check if we have a valid object */
	if(db == NULL || db->parent.type != CLASS_TYPE_DB)
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		assert(0);
	}

	if( recordIdx == db->parent.recordQty )
	{
			fprintf( stderr, "%s error: record requested %d => record Qty %d\n",
				id, recordIdx, db->parent.recordQty );
			assert(0);
	}

	db->fieldIdx	= 0;
	while( strcmp( fieldName, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if(db->fieldIdx == db->fieldQty)
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, fieldName, db->parent.path );
			fflush(stderr);
			assert(0);
		}
	}	

	return(db->record[recordIdx][db->fieldIdx]);
}

==> portmanager-0.4.1.tar.gz: portmanager-0.4.1/libMG/src/MGdbGet.c <==
/************************************************************************/
/*	Copyright (C) 2005  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

char*	MGdbGet(classDb* db, int recordIdx, char* fieldName )
{
	char	id[]	= "MGdbGet";

	/* check if we have a valid object */
	if(db == NULL || db->parent.type != CLASS_TYPE_DB)
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		assert(0);
	}

	if( recordIdx == db->parent.recordQty )
	{
			fprintf( stderr, "%s warning: record requested %d => record Qty %d\n",
				id, recordIdx, db->parent.recordQty );
			return( NULL );
	}

	db->fieldIdx	= 0;
	while( strcmp( fieldName, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if(db->fieldIdx == db->fieldQty)
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, fieldName, db->parent.path );
			fflush(stderr);
			assert(0);
		}
	}	

	return(db->record[recordIdx][db->fieldIdx]);
}
